<?php
/**
 * The template for displaying archive pages.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package pando
 */

get_header(); ?>

<?php 
	//Layout Variables
	$layout_style = get_theme_mod( 'layout_custom', 'sidebar_right' );
	if ( $layout_style == 'sidebar_right' ) : 
		$layout_content_class = 'col-sm-8';
		$layout_sidebar_class = 'col-sm-4';
	elseif ( $layout_style == 'sidebar_left' ) :
		$layout_content_class = 'col-sm-8 col-sm-push-4';
		$layout_sidebar_class = 'col-sm-4 col-sm-pull-8';
	elseif ( $layout_style == 'no_sidebar' ) :
		$layout_content_class = 'without-sidebar';
		$layout_sidebar_class = 'no-sidebar';
	endif;

	//Blog Style
	$layout_blog_style = get_theme_mod( 'layout_blog_style', 'default' );
	if ( $layout_blog_style == 'masonry' ) {
		$layout_blog_class = 'bearr-blog-masonry';
	}
	else {
		$layout_blog_class = 'bearr-blog-default';
	} 
?>
	

	<!-- == CONTENT AREA == -->
	<?php 
		$background_check = get_theme_mod( 'blog_custom_bg', '0' );
		if ( $background_check == 1 ) {
			$blog_bg_image = esc_url(get_theme_mod( 'blog_bg_image', '' ));
		}
		else {
			$blog_bg_image = esc_url(get_theme_mod( 'body_bg_image', '' ));
		}
	?>
	<?php  ?>
	<div id="primary" class="content-area content-area-blog" style="background-image: url(<?php echo esc_url($blog_bg_image); ?>)">	

		<!-- == Page Heading == -->
		<div class="bearr-page-heading">
		    <div class="container">
		        <div class="row">
		            <div class="col-xs-12">
		                <?php the_archive_title( '<h1 class="page-title">', '</h1>' ); ?>
		                <?php $page_subtitle = rwmb_meta( 'bearr_page_subtitle' ); ?> 
	                    <?php if ( !empty( $page_subtitle ) ) : ?>
	                        <p class="page-tagline"><?php the_archive_description(); ?></p>      
		                <?php endif; ?>
	                </div>
		        </div>
		    </div>
		</div>
		<!-- == /Page Heading == -->

		<div class="container">
			<!-- row -->
			<div class="row">
				<!-- col -->
				<div class="<?php echo esc_attr( $layout_content_class ); ?>">
					<!-- main -->
					<main id="main" class="site-main" role="main">
						<?php
						if ( have_posts() ) :

							if ( is_home() && ! is_front_page() ) : ?>
								<header>
									<h1 class="page-title screen-reader-text"><?php single_post_title(); ?></h1>
								</header>

							<?php
							endif; ?>

							<div class="<?php echo esc_attr($layout_blog_class); ?>">
								<?php
								/* Start the Loop */
								while ( have_posts() ) : the_post();

									/*
									 * Include the Post-Format-specific template for the content.
									 * If you want to override this in a child theme, then include a file
									 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
									 */
									get_template_part( 'template-parts/content', get_post_format() );

								endwhile; ?>
							</div>
							
							<?php the_posts_navigation();

						else :

							get_template_part( 'template-parts/content', 'none' );

						endif; ?>

					</main>
					<!-- /main -->
				</div>
				<!-- /col -->
				<!-- col -->
				<div class="<?php echo esc_attr( $layout_sidebar_class ); ?>">
					<?php get_sidebar(); ?>
				</div>
				<!-- /col -->
			</div>
			<!-- /row -->
		</div>		
	</div>
	<!-- == /CONTENT AREA == -->

<?php get_footer(); ?>