<?php
/**
 * WP-Less and CSS/LESS Files Configuration
 *
 *
 * @package pando
 */

function bearr_fonts_url() {
    $font_url = '';
    
    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'pandowp' ) ) {
        $font_url = add_query_arg( 'family', 'Poppins:300,400,700,900', "//fonts.googleapis.com/css" );
    }
    return $font_url;
}

//Without LESS
function bearr_noless_enqueue_styles(){	
	//Fonts
	wp_enqueue_style( 'bearr-fonts', bearr_fonts_url(), array(), '1.0.0' );
	//Compiled CSS
	wp_enqueue_style( 'bearr-theme-style', get_template_directory_uri() . '/css/styles.css' );
}

//With LESS
function bearr_less_enqueue_styles(){
	$less = WPLessPlugin::getInstance();
	wp_enqueue_style('theme-main', get_template_directory_uri() . '/css/styles.less');
	$less->dispatch();

	//Fonts
	wp_enqueue_style( 'bearr-fonts', bearr_fonts_url(), array(), '1.0.0' );

	$force_case = get_theme_mod('typography_forcecase', '1' );
	if ( $force_case == '1') {
		$less->addVariable('force-case', 'uppercase' );
	}
	else {
		$less->addVariable('force-case', 'none' );
	}

	//====== Variables
	//Colors
	$color1 = get_theme_mod('color_one', '#395abd' );
	$less->addVariable('color1', $color1);

	$color2 = get_theme_mod('color_two', '#281b9f' );
	$less->addVariable('color2', $color2 );

	$less->addVariable('title-color', get_theme_mod('color_title', '#393939' ));
	$less->addVariable('text-color', get_theme_mod('color_text', '#555555' ));


	//Body BG
	$less->addVariable('body-bg', get_theme_mod('body_bg', '#f4f4f4' ));

	$background_check = get_theme_mod( 'blog_custom_bg', '0' );
	if ( $background_check == 1 ) {
		$less->addVariable('blog-bg', get_theme_mod('blog_bg', '#f4f4f4' ));		
	}
	else {
		$less->addVariable('blog-bg', get_theme_mod('body_bg', '#f4f4f4' ));
	}


	//Top Bar - BG
	$less->addVariable('topbar-bg', get_theme_mod('topbar_bg', '@color1' ));
	$less->addVariable('topbar-color', get_theme_mod('topbar_color', '#ffffff' ));

	//Header
	$less->addVariable('header-bg', get_theme_mod('header_bg', '#ffffff' ));
	$less->addVariable('header-color', get_theme_mod('header_color', '#333333' ));
	$less->addVariable('header-color-hover', get_theme_mod('header_color_hover', '#333333' ));
	

	$menu_style = get_theme_mod('menu_style', 'clean' );
	if ( $menu_style == 'bordered') {
		$less->addVariable('menu-link-bg-hover', 'transparent');
		$less->addVariable('menu-link-color-hover', '@header-color-hover');
		$less->addVariable('menu-link-border-color', 'transparent');
		$less->addVariable('menu-link-border-radius', '0px');
		$less->addVariable('menu-link-border-size', '2px');
		$less->addVariable('menu-link-after-display', 'none');
	}
	else if ( $menu_style == 'borderedtop') {
		$less->addVariable('menu-link-bg-hover', 'transparent');
		$less->addVariable('menu-link-color-hover', '@header-color-hover');
		$less->addVariable('menu-link-border-color', 'transparent');
		$less->addVariable('menu-link-border-radius', '0px');
		$less->addVariable('menu-link-border-size', '2px 0 0 0');
		$less->addVariable('menu-link-after-display', 'none');
	}
	else if ( $menu_style == 'borderedbottom') {
		$less->addVariable('menu-link-bg-hover', 'transparent');
		$less->addVariable('menu-link-color-hover', '@header-color-hover');
		$less->addVariable('menu-link-border-color', 'transparent');
		$less->addVariable('menu-link-border-radius', '0px');
		$less->addVariable('menu-link-border-size', '0 0 0 0');
		$less->addVariable('menu-link-after-display', 'block');
	}
	else if ( $menu_style == 'withbg') {
		$less->addVariable('menu-link-bg-hover', '@header-color-hover');
		$less->addVariable('menu-link-color-hover', '#ffffff');
		$less->addVariable('menu-link-border-color', 'transparent');
		$less->addVariable('menu-link-border-radius', '6px');
		$less->addVariable('menu-link-border-size', '0 0 0 0');
		$less->addVariable('menu-link-after-display', 'none');
	}
	else {
		$less->addVariable('menu-link-bg-hover', 'transparent');
		$less->addVariable('menu-link-color-hover', '@header-color-hover');
		$less->addVariable('menu-link-border-color', 'transparent');
		$less->addVariable('menu-link-border-radius', '0px');
		$less->addVariable('menu-link-border-size', '0px');
		$less->addVariable('menu-link-after-display', 'none');
	}


	//Footer
	$less->addVariable('footer-bg', get_theme_mod('footer_bg', '#333333' ));
	$less->addVariable('footer-color', get_theme_mod('footer_color', '#ffffff' ));

	//Fonts
	$font1 = get_theme_mod( 'font1', array() );
	$font1_output = '';
	if ( isset( $font1['font-family'] ) ) {
		$font1_output = $font1 ['font-family'];
	}
	else {
		$font1_output = 'Poppins, sans-serif';
	}
	$less->addVariable('font1', $font1_output);

	$font2 = get_theme_mod( 'font2', array() );
	$font2_output = '';
	if ( isset( $font2['font-family'] ) ) {
		$font2_output = $font2 ['font-family'];
	}
	else {
		$font2_output = 'Poppins, sans-serif';
	}
	$less->addVariable('font2', $font2_output);

	//Others
	$less->addVariable('loaderbg', get_theme_mod('loader_bg_color', '@color1' ));

	//Body Classes
	$page_transition = get_theme_mod('general_page_transition', 'on' );
	if ( $page_transition == 'on') {
		add_filter( 'body_class', function( $classes ) {
		    return array_merge( $classes, array( 'with-page-transition', 'with-page-transition-hide' ) );
		} );
	}		

	//Gradient
	$color_style = get_theme_mod('general_color_style', 'gradient' );
	if ( $color_style == 'gradient') {
		$less->addVariable('gradient-bg', 'linear-gradient(to right, @color1-light, @color1-dark)');
		$less->addVariable('gradient-bg2', 'linear-gradient(to right, @color1-lighter, @color1-darker)');
		$less->addVariable('gradient-border', '-webkit-linear-gradient(45deg,@color1-lighter,@color1-darker) 10 stretch');
	}
	else {
		$less->addVariable('gradient-bg', 'linear-gradient(to right, @color1, @color1)');
		$less->addVariable('gradient-bg2', 'linear-gradient(to right, @color1, @color1)');
		$less->addVariable('gradient-border', '-webkit-linear-gradient(45deg,@color1,@color1) 10 stretch');
	}

	//Elements Style
	$elements_style = get_theme_mod('layout_elements_style', 'boxed' );
	if ( $elements_style == 'boxed' ) {
		$less->addVariable('layout-box-padding', '20px');
		$less->addVariable('layout-box-bg', get_theme_mod('boxed_elements_bg', '#ffffff' ) );
	}
	else {
		$less->addVariable('layout-box-padding', '0px');
		$less->addVariable('layout-box-bg', 'transparent');
	}

	$elements_style_border = get_theme_mod('general_elements_border', 'off' );
	if ( $elements_style_border == 'on' ) {
		$less->addVariable('layout-box-border', '1px solid @border-color');
	}
	else {
		$less->addVariable('layout-box-border', '0px solid @border-color');
	}

	$elements_style_radius = get_theme_mod('general_elements_border_radius', '6' );
	$elements_style_radius_px = $elements_style_radius . 'px';
	$less->addVariable('layout-box-border-radius', $elements_style_radius_px);

	$titles_style = get_theme_mod('layout_titles_style', 'withborder' );
	if ( $titles_style == 'withborder' ) {
		$less->addVariable('layout-title-border', '4px solid');
		$less->addVariable('layout-title-padding',  '10px 20px' );
	}
	else {
		$less->addVariable('layout-title-border', '0px solid');
		$less->addVariable('layout-title-padding',  '0px 0px' );
	}
}

//If have WP-LESS active
if ( class_exists('WPLessPlugin') ) {
  add_action('wp_enqueue_scripts', 'bearr_less_enqueue_styles');
}

//Else, loads the compiled CSS (color and fonts customization will not work)
else {	
  add_action('wp_enqueue_scripts', 'bearr_noless_enqueue_styles');
}


