<?php
/**
 * bearr functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package pando
 */

if ( ! function_exists( 'pandoprefix_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function pandoprefix_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on bearr, use a find and replace
	 * to change 'pandowp' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'pandowp', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 850, 450, true, true);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'pandowp' ),
		'secondary' => esc_html__( 'Secondary', 'pandowp' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
		'audio',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery'
	) );

	/*	Image Sizes
	 */
	add_image_size( 'pandoprefix_imgsize_1', 1170, 800, true ); 
	add_image_size( 'bearr-logo', 314, 90 );
	add_image_size( 'pandoprefix_team_photo', 265, 325, true ); 
	add_image_size( 'pandoprefix_client_logo', 225, 170 ); 
	add_image_size( 'pandoprefix_full_hd', 1920, 1080, true ); 
	
	/*	Native Site Logo
	 */
	add_theme_support( 'custom-logo', array(
		'size' => 'bearr-logo'
	) );

}
endif;
add_action( 'after_setup_theme', 'pandoprefix_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function pandoprefix_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'pandoprefix_content_width', 750 );
}
add_action( 'after_setup_theme', 'pandoprefix_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function pandoprefix_widgets_init() {
	
	//Sidebar
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'pandowp' ),
		'id'            => 'sidebar-1',
		'description'   =>  esc_html__( 'Widgets will be shown on the main sidebar.', 'pandowp' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	//Footer 1
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1', 'pandowp' ),
		'id'            => 'widgets-footer-1',
		'description'   => esc_html__('Widget shown in the first column of the footer.', 'pandowp' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	//Footer 2
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2', 'pandowp' ),
		'id'            => 'widgets-footer-2',
		'description'   => esc_html__( 'Widget shown in the second column of the footer.', 'pandowp' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	//Footer 3
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3', 'pandowp' ),
		'id'            => 'widgets-footer-3',
		'description'   => esc_html__( 'Widget shown in the third column of the footer.', 'pandowp' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

	//Footer 4
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 4', 'pandowp' ),
		'id'            => 'widgets-footer-4',
		'description'   => esc_html__( 'Widget shown in the last column of the footer.', 'pandowp' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );

}
add_action( 'widgets_init', 'pandoprefix_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function pandoprefix_scripts() {
	
	wp_enqueue_style( 'bearr-style', get_stylesheet_uri() );

	wp_enqueue_script( 'bearr-navigation', get_template_directory_uri() . '/js/navigation.js', array('jquery'), '20151215', true );

	wp_enqueue_script( 'bearr-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array('jquery'), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	//bootstrap
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/framework/js/vendor/bootstrap/css/bootstrap.min.css' );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/framework/js/vendor/bootstrap/js/bootstrap.min.js', array('jquery'), '20151215', true );

	//font awesomes
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/framework/js/vendor/font-awesome/css/font-awesome.min.css' );

	//Waypoints		
	wp_enqueue_script( 'imagesloaded', get_template_directory_uri() . '/framework/js/vendor/imagesloaded.pkgd.min.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/framework/js/vendor/waypoints.min.js', array('jquery'), '20151215', true );	

	//Isotope
	wp_enqueue_script( 'imagesloaded', get_template_directory_uri() . '/framework/vendor/imagesloaded.pkgd.min.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'isotope', get_template_directory_uri() . '/framework/js/vendor/isotope/js/isotope.pkgd.min.js', array('jquery'), '20151215', true );
	
	//Woocommerce
	if ( class_exists( 'woocommerce' ) ) {		
		wp_enqueue_script( 'bearr-woocommerce', get_template_directory_uri() . '/js/woocommerce.js', array('jquery'), '20151215', true );
	}

	//theme files	
	wp_enqueue_script( 'bearr-theme-js', get_template_directory_uri() . '/js/main.js', array('jquery'), '20151215', true );
}
add_action( 'wp_enqueue_scripts', 'pandoprefix_scripts' );
/**
 * CSS Config
 * Configure and enqueue the theme styles
 */
require get_template_directory() . '/framework/css-config.php';
/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * navigation bootstrap
 */
require get_template_directory() . '/framework/bearr_wp_bootstrap_navwalker.php';

/**
 * Custom Widgets
 */
require get_template_directory() . '/inc/custom-widgets.php';
/**
 * TGM Plugin Activation
 */
require_once get_template_directory() . '/framework/tgm-plugin-activation/class-tgm-plugin-activation.php';
require get_template_directory() . '/framework/tgm-config.php';
/**
 * Kirki
 */
require_once get_template_directory() . '/framework/kirki/bearr-theme-kirki.php';
require get_template_directory() . '/framework/kirki/include-kirki.php';
require get_template_directory() . '/framework/kirki-config.php';
/**
 * One click Demo Import
 */
require get_template_directory() . '/framework/one-click-demo-install-config.php';
/**
 * BeaRR Theme Features Plugin - Theme Features Setup
 */
require get_template_directory() . '/framework/bearr-config.php';
/**
 * WooCommerce
 */
require get_template_directory() . '/framework/bearr-woocommerce.php';
/**
 * King Composer
 */
define('KC_LICENSE', 'l483kg4m-jxbv-ju7k-or7h-yhgd-q3jl1ec3fqyi');