<?php
/**
 * The template for displaying all pages.
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     2.0.0
 */

get_header(); ?>

<?php //Layout Variables
$layout_style = get_theme_mod( 'layout_custom', 'sidebar_right' );
$woo_sidebar = get_theme_mod( 'woo_use_col', 'true' );

if ( $layout_style == 'sidebar_right' && is_active_sidebar( 'sidebarwoo' ) ) :

	$layout_content_class = 'col-sm-9';
	$layout_sidebar_class = 'col-sm-3';


elseif ( $layout_style == 'sidebar_left'  && is_active_sidebar( 'sidebarwoo' ) ) :

	$layout_content_class = 'col-sm-9 col-sm-push-3';
	$layout_sidebar_class = 'col-sm-3 col-sm-pull-9';

else :

	$layout_content_class = '';
	$layout_sidebar_class = 'no-sidebar';

endif; ?>	

	<!-- == CONTENT AREA == -->
	<?php $bg_image = esc_url(get_theme_mod( 'body_bg_image', '' )); ?>
	<div id="primary" class="content-area" style="background-image: url(<?php echo esc_url($bg_image); ?>)">

		<!-- == Page Heading == -->
		<?php get_template_part( 'template-parts/wc', 'custom-header' ); ?>			
		<!-- == /Page Heading == -->	

		<div class="container">
			<!-- row -->
			<div class="row">
				<!-- col -->				
				<div class="<?php echo esc_attr( $layout_content_class ); ?>">
					
					<?php if ( have_posts() ) : ?>

					<?php
						/**
						 * woocommerce_before_shop_loop hook
						 *
						 * @hooked woocommerce_result_count - 20
						 * @hooked woocommerce_catalog_ordering - 30
						 */
						do_action( 'woocommerce_before_shop_loop' );
					?>

					<?php woocommerce_product_loop_start(); ?>

						<?php woocommerce_product_subcategories(); ?>

						<?php while ( have_posts() ) : the_post(); ?>

							<?php wc_get_template_part( 'content', 'product' ); ?>

						<?php endwhile; // end of the loop. ?>

					<?php woocommerce_product_loop_end(); ?>

					<?php
						/**
						 * woocommerce_after_shop_loop hook
						 *
						 * @hooked woocommerce_pagination - 10
						 */
						do_action( 'woocommerce_after_shop_loop' );
					?>

				<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>

					<?php
						/**
						 * woocommerce_no_products_found hook.
						 *
						 * @hooked wc_no_products_found - 10
						 */
						do_action( 'woocommerce_no_products_found' );
					?>

				<?php endif; ?>
				</div>
				<!-- /col -->
				<!-- col -->
				<?php if ( is_active_sidebar( 'sidebarwoo' ) ) : ?>	

					<div class="<?php echo esc_attr( $layout_sidebar_class ); ?>">
						<aside id="secondary" class="widget-area sidebar-area" role="complementary">	
							<?php dynamic_sidebar( 'sidebarwoo' ); ?>
						</aside><!-- #secondary -->
					</div>

				<?php endif; ?>
				<!-- /col -->
			</div>
			<!-- /row -->
		</div>		
	</div>
	<!-- == /CONTENT AREA == -->

<?php get_footer(); ?>